==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/master_information_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::MasterInformationController < CoreModelsController
    # GET /people_and_companies/master_information
    # GET /people_and_companies/master_information.json
    def index
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_master_information }
      end
    end

    # GET /people_and_companies/master_information/1
    # GET /people_and_companies/master_information/1.json
    def show
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_master_information }
      end
    end

    # GET /people_and_companies/master_information/new
    # GET /people_and_companies/master_information/new.json
    def new
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_master_information }
      end
    end

    # GET /people_and_companies/master_information/1/edit
    def edit
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.find(params[:id])
    end

    # POST /people_and_companies/master_information
    # POST /people_and_companies/master_information.json
    def create
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.new(params[:people_and_companies_master_information])

      respond_to do |format|
        if @people_and_companies_master_information.save
          format.html { redirect_to @people_and_companies_master_information, :notice => 'Master information was successfully created.' }
          format.json { render :json => @people_and_companies_master_information, :status => :created, :location => @people_and_companies_master_information }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_master_information.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/master_information/1
    # PUT /people_and_companies/master_information/1.json
    def update
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.find(params[:id])

      respond_to do |format|
        if @people_and_companies_master_information.update_attributes(params[:people_and_companies_master_information])
          format.html { redirect_to @people_and_companies_master_information, :notice => 'Master information was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_master_information.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/master_information/1
    # DELETE /people_and_companies/master_information/1.json
    def destroy
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.find(params[:id])
      @people_and_companies_master_information.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_master_information_index_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/master_information_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::MasterInformationController < CoreModelsController
    # GET /people_and_companies/master_information
    # GET /people_and_companies/master_information.json
    def index
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_master_information }
      end
    end

    # GET /people_and_companies/master_information/1
    # GET /people_and_companies/master_information/1.json
    def show
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_master_information }
      end
    end

    # GET /people_and_companies/master_information/new
    # GET /people_and_companies/master_information/new.json
    def new
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_master_information }
      end
    end

    # GET /people_and_companies/master_information/1/edit
    def edit
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.find(params[:id])
    end

    # POST /people_and_companies/master_information
    # POST /people_and_companies/master_information.json
    def create
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.new(params[:people_and_companies_master_information])

      respond_to do |format|
        if @people_and_companies_master_information.save
          format.html { redirect_to @people_and_companies_master_information, :notice => 'Master information was successfully created.' }
          format.json { render :json => @people_and_companies_master_information, :status => :created, :location => @people_and_companies_master_information }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_master_information.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/master_information/1
    # PUT /people_and_companies/master_information/1.json
    def update
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.find(params[:id])

      respond_to do |format|
        if @people_and_companies_master_information.update(params[:people_and_companies_master_information])
          format.html { redirect_to @people_and_companies_master_information, :notice => 'Master information was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_master_information.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/master_information/1
    # DELETE /people_and_companies/master_information/1.json
    def destroy
      @people_and_companies_master_information = PeopleAndCompanies::MasterInformation.find(params[:id])
      @people_and_companies_master_information.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_master_information_index_url }
        format.json { head :no_content }
      end
    end
  end
end
